@@ -1,6 +1,6 @@
 pref("browser.aboutConfig.showWarning", false);
+pref("browser.download.showTorWarning", false);
 pref("browser.tabs.warnOnClose", false);
 pref("devtools.chrome.enabled", true);
-pref("extensions.torbutton.launch_warning", false);
 pref("intl.language_notification.shown", true);
 pref("privacy.prioritizeonions.showNotification", false);
